@@ -1,6 +1,6 @@
-from enum import StrEnum
+from enum import Enum
 
 
-class CloudProviders(StrEnum):
+class CloudProviders(str, Enum):
     aws = 'amazon_web_services'
     gcs = 'google_cloud_storage'
